"""Check if the inparanoid output has been previously produced"""
import sys
import os
import argparse

########### FUNCTIONS ############
def get_params():
    """Parse and analyse command line parameters."""
    parser = argparse.ArgumentParser()
    #start adding the command line options
    #parser.add_argument('echo', help='echo the string you use here')
    parser.add_argument('-f1', '--file1', type=str, required=True, help='First genome input to inparanoid.', default=None)
    parser.add_argument('-f2', '--file2', type=str, required=True, help='Second genome input to inparanoid.', default=None)
    parser.add_argument('--debug', required=False, help='Print some debug output.', default=False, action='store_true')
    args = parser.parse_args()
    return args


########### MAIN ############

def main():
    #Get the parameters
    args = get_params()
    #start setting the needed variables
    debug = args.debug
    #set the file paths
    r1 = os.path.realpath(args.file1)
    r2 = os.path.realpath(args.file2)
    br1 = os.path.basename(r1)
    br2 = os.path.basename(r2)
    blastRunName = '%s-%s'%(br1, br2)
    '''
    if debug:
        print(br1)
        print(br2)
        print(blastRunName)
    '''
    #it expects the shared directory to be on the same level of the current working directory
    # eg., cwd = /home/my_dir/, then shared_dir = /home/shared_dir/ or (../shared_dir)
    root = os.getcwd()
    sharedDir = '%s/shared_output/'%(os.path.dirname(root))
    if not os.path.isdir(sharedDir):
        sys.exit('The shared directory %s does not exist! Please create it before executing the script'%sharedDir)
    #check if the file already exists
    blastRunPath = '%s%s'%(sharedDir, blastRunName)
    #copy the file in the current directory
    import shutil
    #copy the file if exists
    if os.path.isfile(blastRunPath):
        shutil.copy2(blastRunPath, root)
        if debug:
            sys.stdout.write('Successfully copied blast run %s to the inparanoid run directory\n%s\n'%(blastRunName, root))
            sys.stdout.write('\nThe blast run for %s can be skipped!\n'%(blastRunName))
        sys.exit(0)
    else:
        if debug:
            sys.stdout.write('No blast run found in the shared directory for %s.\n'%(blastRunName))
            sys.stdout.write('The blast run for %s is required!\n'%(blastRunName))
        sys.exit(-1) #in perl would correspond to 65280 exit code
if __name__ == "__main__":
    main()
